import { select, 
        	json, 
        	geoPath, 
        	geoMercator, 
        	geoOrthographic, 
        	geoStereographic, 
        	geoEquirectangular, 
        	geoNaturalEarth1,
        	geoArmadillo, 
        	tsv, 
        	zoom,
        	event
       } from 'd3';

import { feature } from 'topojson';
//geopath converts dataPath into SVGpath string that we can use in SVG paths
// geoMercator is a map projections

const svg = select('svg');

//const projection = geoOrthographic();
//const projection = geoMercator();
//const projection = geoStereographic();
//const projection = geoEquirectangular();
const projection = geoNaturalEarth1();
//const projection = geoArmadillo();


const pathGenerator = geoPath().projection(projection)

const g = svg.append('g');

g.append('path')
	// adding classes
  .attr('class', 'sphere')
	.attr('d', pathGenerator({type: 'Sphere'}));

// zoom block of code



svg.call(zoom().on('zoom', () =>{
  g.attr('transform', event.transform);
}));








// in order to execute mulitple promise files
// you can load the 110m for a 'rougher' boarder
Promise.all([
  tsv('https://unpkg.com/world-atlas@1.1.4/world/50m.tsv'),
  json('https://unpkg.com/world-atlas@1.1.4/world/50m.json')

  
]).then(([tsvData, topoJSONdata]) => {
  
  const countryName = tsvData.reduce((accumulator, d) => {
    accumulator[d.iso_n3] = d.name;
    return accumulator;
  }, {});
  
  // clean version of the the code block above (to build the look up table)
  /*
  const countryName = {};
  tsvData.forEach(d => {
    countryName[d.iso_n3] = d.name;
  });
  
  */
   //comment: alternate - simplified code 
  //comment: create a data join
  //comment: selectAll 'path' then pass in the features
  // comment: then append the paths(i.e. shapes to each of the elements)
  // comment: pathGenerator does the same thing as d=> pathGenerator(d))	
  const countries = feature(topoJSONdata, topoJSONdata.objects.countries);
  g.selectAll('path').data(countries.features)
  		.enter().append('path')
  			.attr('class', 'country')
  			.attr('d', pathGenerator)
  		.append('title')
  			.text(d=> countryName[d.id]);
});

